
/*
 * -----------------------------------------------------------------------------
 * File  Name     : AesopdocumentDAO.java
 * Description    : DAO class
 * Special Logics :
 * @author        : Suh Hyuck Jun
 * @version       : 1.0
 * @Date          : 2005.12.24
 *------------------------------------------------------------------------------
 * History :
 *  DATE              AUTHOR          DESCRIPTION
 * -----------      -------------    -------------------
 *  2005.12.24      Suh, Hyuck Jun    Initial Release
 *------------------------------------------------------------------------------
 * Copyright(c) 2004,  All rights reserved.
 *
 * NOTICE !    You can not copy or redistribute this code.
 *
 */
package cc.struts.cian3.aesopdocument.dao;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import cc.struts.cian3.dao.LoggableStatement;
import cc.struts.cian3.dao.SuperDAO;
import cc.struts.cian3.dto.ComboDTO;
import cc.struts.cian3.exception.DatabaseException;
import cc.struts.cian3.aesopdocument.dto.AesopdocumentDTO;


public class AesopdocumentDAO extends SuperDAO {
    static private final Log log = LogFactory.getLog(AesopdocumentDAO.class);



    public int insertAesopdocument( AesopdocumentDTO aesopdocument ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "INSERT INTO TB_DOCUMENT(                                 \n" );
        query.append( "                      c_document_eid                     \n" );
        query.append( "                     ,c_name                             \n" );
        query.append( "                     ,c_user_eid                         \n" );
        query.append( "                     ,c_groupcode                        \n" );
        query.append( "                     ,c_del_yn                           \n" );
        query.append( "                     ,c_publish_yn                       \n" );
        query.append( "              )VALUES(                                   \n" );
        query.append( "                      ?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,'N'                                \n" );
        query.append( "                     ,'N'                                \n" );        
        query.append( "              )                                          \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();
        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesopdocument.getDocument_eid() );
            pstmt.setString( 2, aesopdocument.getName() );
            pstmt.setInt   ( 3, aesopdocument.getUser_eid() );
            pstmt.setInt   ( 4, aesopdocument.getGroupcode() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int selectSeq() throws DatabaseException {
        int count = 0;
        StringBuffer query = new StringBuffer();
        query.append( "SELECT MAX(c_document_eid) + 1 eid from TB_DOCUMENT      \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
              count= rs.getInt("eid");
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return count;

    }


    public AesopdocumentDTO[] selectAesopdocumentList( AesopdocumentDTO aesopdocument ) throws DatabaseException {
        AesopdocumentDTO[] arrDto = null;
        ArrayList list = new ArrayList();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        a.c_document_eid  c_document_eid                 \n" );
        query.append( "       ,a.c_name          c_name                         \n" );
        query.append( "       ,a.c_user_eid      c_user_eid                     \n" );
        query.append( "       ,c.c_name          c_user_eid_lb                  \n" );
        query.append( "       ,a.c_groupcode     c_groupcode                    \n" );
        query.append( "       ,b.name            c_groupcode_lb                 \n" );
        query.append( "       ,a.c_publish_yn    c_publish_yn                   \n" );
        query.append( "  FROM TB_DOCUMENT a                                     \n" );
        query.append( "      ,TB_CODE b                                         \n" );
        query.append( "      ,TB_USER c                                         \n" );
        query.append( " WHERE a.c_del_yn = 'N'                                  \n" );
        query.append( "   AND a.c_publish_yn = 'N'                              \n" );
        query.append( "   AND a.c_groupcode = b.class_id                        \n" );
        query.append( "   AND b.class_group = 2101                              \n" );
        query.append( "   AND a.c_user_eid = c.c_user_eid                       \n" );
        

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            while ( rs.next() ){
                AesopdocumentDTO dto = new AesopdocumentDTO();
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setName( rs.getString( "c_name" ) );
                dto.setUser_eid( rs.getInt( "c_user_eid" ) );
                dto.setUser_eid_lb( rs.getString( "c_user_eid_lb" ) );
                dto.setGroupcode( rs.getInt( "c_groupcode" ) );
                dto.setGroupcode_lb( rs.getString( "c_groupcode_lb" ) );
                dto.setPublish_yn( rs.getString( "c_publish_yn" ) );

                list.add(dto);
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        arrDto = new AesopdocumentDTO[list.size()];
        list.toArray( arrDto );
        return arrDto;

    }

    public AesopdocumentDTO selectAesopdocument( AesopdocumentDTO aesopdocument ) throws DatabaseException {
        AesopdocumentDTO dto = new AesopdocumentDTO();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        a.c_document_eid  c_document_eid                 \n" );
        query.append( "       ,a.c_name          c_name                         \n" );
        query.append( "       ,a.c_user_eid      c_user_eid                     \n" );
        query.append( "       ,c.c_name          c_user_eid_lb                  \n" );
        query.append( "       ,a.c_groupcode     c_groupcode                    \n" );
        query.append( "       ,b.name            c_groupcode_lb                 \n" );
        query.append( "       ,a.c_publish_yn    c_publish_yn                   \n" );
        query.append( "  FROM TB_DOCUMENT a                                     \n" );
        query.append( "      ,TB_CODE b                                         \n" );
        query.append( "      ,TB_USER c                                         \n" );
        query.append( " WHERE  c_del_yn = 'N'                                   \n" );
        query.append( "   AND  a.c_groupcode = b.class_id                       \n" );
        query.append( "   AND  b.class_group = 2101                             \n" );
        query.append( "   AND  a.c_document_eid = ?                             \n" );
        query.append( "   AND  a.c_user_eid = c.c_user_eid                      \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesopdocument.getDocument_eid()); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setName( rs.getString( "c_name" ) );
                dto.setUser_eid( rs.getInt( "c_user_eid" ) );
                dto.setUser_eid_lb( rs.getString( "c_user_eid_lb" ) );
                dto.setGroupcode( rs.getInt( "c_groupcode" ) );
                dto.setGroupcode_lb( rs.getString( "c_groupcode_lb" ) );
                dto.setPublish_yn( rs.getString( "c_publish_yn" ) );
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return dto;

    }



    public int updateAesopdocument( AesopdocumentDTO aesopdocument ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_DOCUMENT SET                                   \n" );
        query.append( "        c_name = ?                                       \n" );
        query.append( "       ,c_user_eid = ?                                   \n" );
        query.append( "       ,c_groupcode = ?                                  \n" );
        query.append( " WHERE c_document_eid = ?                                \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setString( 1, aesopdocument.getName() );
            pstmt.setInt   ( 2, aesopdocument.getUser_eid() );
            pstmt.setInt   ( 3, aesopdocument.getGroupcode() );
            pstmt.setInt   ( 4, aesopdocument.getDocument_eid() ); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }


    public int deleteAesopdocument( AesopdocumentDTO aesopdocument ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_DOCUMENT                                       \n" );
        query.append( "   SET c_del_yn = 'Y'                                    \n" );
        query.append( " WHERE c_document_eid = ?                                \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesopdocument.getDocument_eid() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int publishAesopdocument( AesopdocumentDTO aesopdocument ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_DOCUMENT                                       \n" );
        query.append( "   SET c_publish_yn = 'Y'                                \n" );
        query.append( " WHERE c_document_eid = ?                                \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesopdocument.getDocument_eid() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public Collection selectUserEidCodeList() throws DatabaseException {
    	
    	ArrayList list = new ArrayList();
    	
    	StringBuffer query = new StringBuffer();
        query.append( "SELECT c_name        pkey                       \n");
        query.append( "      ,c_user_eid    combovalue                 \n");
        query.append( "  from TB_USER                                  \n");
        query.append( " WHERE c_use_yn ='Y'                            \n");
        query.append( "   AND c_delete_yn = 'N'                        \n");
        query.append( "order by c_name                                 \n");
        
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();
        
        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());
            
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );
            
            rs = pstmt.executeQuery();
            
            while ( rs.next() ){
            	list.add( new ComboDTO( rs.getInt( "combovalue"), rs.getString( "pkey")));
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        
        return list;
    	
    }

}
