
/*
 * -----------------------------------------------------------------------------
 * File  Name     : AesopinspectionlistDAO.java
 * Description    : DAO class
 * Special Logics :
 * @author        : Suh Hyuck Jun
 * @version       : 1.0
 * @Date          : 2005.12.24
 *------------------------------------------------------------------------------
 * History :
 *  DATE              AUTHOR          DESCRIPTION
 * -----------      -------------    -------------------
 *  2005.12.24      Suh, Hyuck Jun    Initial Release
 *------------------------------------------------------------------------------
 * Copyright(c) 2004,  All rights reserved.
 *
 * NOTICE !    You can not copy or redistribute this code.
 *
 */
package cc.struts.cian3.aesopinspectionlist.dao;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import cc.struts.cian3.dao.LoggableStatement;
import cc.struts.cian3.dao.SuperDAO;
import cc.struts.cian3.exception.DatabaseException;
import cc.struts.cian3.aesopinspectionlist.dto.AesopinspectionlistDTO;
import cc.struts.cian3.aesoppreparationlist.dto.AesoppreparationlistDTO;


public class AesopinspectionlistDAO extends SuperDAO {
    static private final Log log = LogFactory.getLog(AesopinspectionlistDAO.class);



    public int insertAesopinspectionlist( AesopinspectionlistDTO aesopinspectionlist ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "INSERT INTO TB_INSPECTIONLIST(                           \n" );
        query.append( "                      c_user_eid                         \n" );
        query.append( "                     ,c_document_eid                     \n" );
        query.append( "                     ,c_overview_eid                     \n" );
        query.append( "                     ,c_inspection_eid                   \n" );
        query.append( "                     ,c_inspectionlist_eid               \n" );
        query.append( "                     ,c_detect_position                  \n" );
        query.append( "                     ,c_defect_weight                    \n" );
        query.append( "                     ,c_defect_type                      \n" );
        query.append( "                     ,c_stage                            \n" );
        query.append( "                     ,c_comments                         \n" );
        query.append( "                     ,c_fix_yn                           \n" );
        query.append( "                     ,c_fix_time                         \n" );
        query.append( "                     ,c_del_yn                           \n" );
        query.append( "              )VALUES(                                   \n" );
        query.append( "                      ?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,'N'                                \n" );
        query.append( "              )                                          \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();
        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesopinspectionlist.getUser_eid() );
            pstmt.setInt   ( 2, aesopinspectionlist.getDocument_eid() );
            pstmt.setInt   ( 3, aesopinspectionlist.getOverview_eid() );
            pstmt.setInt   ( 4, aesopinspectionlist.getInspection_eid() );
            pstmt.setInt   ( 5, aesopinspectionlist.getInspectionlist_eid() );
            pstmt.setString( 6, aesopinspectionlist.getDetect_position() );
            pstmt.setInt   ( 7, aesopinspectionlist.getDefect_weight() );
            pstmt.setInt   ( 8, aesopinspectionlist.getDefect_type() );
            pstmt.setInt   ( 9, aesopinspectionlist.getStage() );
            pstmt.setString( 10, aesopinspectionlist.getComments() );
            pstmt.setInt   ( 11, aesopinspectionlist.getFix_yn() );
            pstmt.setInt   ( 12, aesopinspectionlist.getFix_time() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int selectSeq( AesopinspectionlistDTO aesopinspectionlist ) throws DatabaseException {
        int count = 0;
        StringBuffer query = new StringBuffer();
        query.append( "SELECT MAX(c_inspectionlist_eid) + 1 eid            \n" );
        query.append( "  FROM TB_INSPECTIONLIST                            \n" );
        query.append( " WHERE c_document_eid = ?                           \n" );
        query.append( "   AND c_overview_eid  = ?                          \n" );
        query.append( "   AND c_user_eid = ?                               \n" );
        query.append( "   AND c_inspection_eid = ?                         \n" );


        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());
        
            pstmt.setInt( 1, aesopinspectionlist.getDocument_eid() );
            pstmt.setInt( 2, aesopinspectionlist.getOverview_eid() );
            pstmt.setInt( 3, aesopinspectionlist.getUser_eid() );
            pstmt.setInt( 4, aesopinspectionlist.getInspection_eid() );
        
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
              count= rs.getInt("eid");
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return count;

    }


    public AesopinspectionlistDTO[] selectAesopinspectionlistList( AesopinspectionlistDTO aesopinspectionlist ) throws DatabaseException {
        AesopinspectionlistDTO[] arrDto = null;
        ArrayList list = new ArrayList();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                    \n" );
        query.append( "        a.c_user_eid                 c_user_eid           \n" );
        query.append( "       ,a.c_document_eid             c_document_eid       \n" );
        query.append( "       ,a.c_overview_eid             c_overview_eid       \n" );
        query.append( "       ,a.c_inspection_eid           c_inspection_eid     \n" );
        query.append( "       ,a.c_inspectionlist_eid       c_inspectionlist_eid \n" );
        query.append( "       ,a.c_detect_position          c_detect_position    \n" );
        query.append( "       ,a.c_defect_weight            c_defect_weight      \n" );
        query.append( "       ,b.name                       c_defect_weight_lb   \n" );
        query.append( "       ,a.c_defect_type              c_defect_type        \n" );
        query.append( "       ,a.c_stage                    c_stage              \n" );
        query.append( "       ,a.c_comments                 c_comments           \n" );
        query.append( "       ,a.c_fix_yn                   c_fix_yn             \n" );
        query.append( "       ,a.c_fix_time                 c_fix_time           \n" );
        query.append( "  FROM TB_INSPECTIONLIST a                                \n" );
        query.append( "      ,TB_CODE b                                          \n" );
        query.append( " WHERE a.c_document_eid = ?                               \n" );
        query.append( "   AND a.c_overview_eid  = ?                              \n" );
        query.append( "   AND a.c_user_eid = ?                                   \n" );
        query.append( "   AND a.c_inspection_eid = ?                             \n" );
        query.append( "   AND a.c_defect_weight = b.class_id                     \n" );
        query.append( "   AND b.class_group = 2104                               \n" );
        query.append( "   AND a.c_del_yn = 'N'                                   \n" );
        
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());
        
            pstmt.setInt( 1, aesopinspectionlist.getDocument_eid() );
            pstmt.setInt( 2, aesopinspectionlist.getOverview_eid() );
            pstmt.setInt( 3, aesopinspectionlist.getUser_eid() );
            pstmt.setInt( 4, aesopinspectionlist.getInspection_eid() );
        
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            while ( rs.next() ){
                AesopinspectionlistDTO dto = new AesopinspectionlistDTO();
                dto.setUser_eid( rs.getInt( "c_user_eid" ) );
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setOverview_eid( rs.getInt( "c_overview_eid" ) );
                dto.setInspection_eid( rs.getInt( "c_inspection_eid" ) );
                dto.setInspectionlist_eid( rs.getInt( "c_inspectionlist_eid" ) );
                dto.setDetect_position( rs.getString( "c_detect_position" ) );
                dto.setDefect_weight( rs.getInt( "c_defect_weight" ) );
                dto.setDefect_weight_lb( rs.getString( "c_defect_weight_lb" ) );
                dto.setDefect_type( rs.getInt( "c_defect_type" ) );
                dto.setStage( rs.getInt( "c_stage" ) );
                dto.setComments( rs.getString( "c_comments" ) );
                dto.setFix_yn( rs.getInt( "c_fix_yn" ) );
                dto.setFix_time( rs.getInt( "c_fix_time" ) );

                list.add(dto);
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        arrDto = new AesopinspectionlistDTO[list.size()];
        list.toArray( arrDto );
        return arrDto;

    }

    public AesopinspectionlistDTO selectAesopinspectionlist( AesopinspectionlistDTO aesopinspectionlist ) throws DatabaseException {
        AesopinspectionlistDTO dto = new AesopinspectionlistDTO();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        c_user_eid                                       \n" );
        query.append( "       ,c_document_eid                                   \n" );
        query.append( "       ,c_overview_eid                                   \n" );
        query.append( "       ,c_inspection_eid                                 \n" );
        query.append( "       ,c_inspectionlist_eid                             \n" );
        query.append( "       ,c_detect_position                                \n" );
        query.append( "       ,c_defect_weight                                  \n" );
        query.append( "       ,c_defect_type                                    \n" );
        query.append( "       ,c_stage                                          \n" );
        query.append( "       ,c_comments                                       \n" );
        query.append( "       ,c_fix_yn                                         \n" );
        query.append( "       ,c_fix_time                                       \n" );
        query.append( "  FROM TB_INSPECTIONLIST                                 \n" );
        query.append( " WHERE c_user_eid = ?                                    \n" );
        query.append( "   AND c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid  = ?                               \n" );
        query.append( "   AND c_inspection_eid = ?                              \n" );
        query.append( "   AND c_inspectionlist_eid = ?                          \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesopinspectionlist.getUser_eid()); 
            pstmt.setInt( 2, aesopinspectionlist.getDocument_eid() );
            pstmt.setInt( 3, aesopinspectionlist.getOverview_eid() );
            pstmt.setInt( 4, aesopinspectionlist.getInspection_eid() );
            pstmt.setInt( 5, aesopinspectionlist.getInspectionlist_eid() );
            
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
                dto.setUser_eid( rs.getInt( "c_user_eid" ) );
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setOverview_eid( rs.getInt( "c_overview_eid" ) );
                dto.setInspection_eid( rs.getInt( "c_inspection_eid" ) );
                dto.setInspectionlist_eid( rs.getInt( "c_inspectionlist_eid" ) );
                dto.setDetect_position( rs.getString( "c_detect_position" ) );
                dto.setDefect_weight( rs.getInt( "c_defect_weight" ) );
                dto.setDefect_type( rs.getInt( "c_defect_type" ) );
                dto.setStage( rs.getInt( "c_stage" ) );
                dto.setComments( rs.getString( "c_comments" ) );
                dto.setFix_yn( rs.getInt( "c_fix_yn" ) );
                dto.setFix_time( rs.getInt( "c_fix_time" ) );
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return dto;

    }



    public int updateAesopinspectionlist( AesopinspectionlistDTO aesopinspectionlist ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_INSPECTIONLIST SET                             \n" );
        query.append( "        c_detect_position = ?                            \n" );
        query.append( "       ,c_defect_weight = ?                              \n" );
        query.append( "       ,c_defect_type = ?                                \n" );
        query.append( "       ,c_stage = ?                                      \n" );
        query.append( "       ,c_comments = ?                                   \n" );
        query.append( "       ,c_fix_yn = ?                                     \n" );
        query.append( "       ,c_fix_time = ?                                   \n" );
        query.append( " WHERE c_user_eid = ?                                    \n" );
        query.append( "   AND c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid = ?                                \n" );
        query.append( "   AND c_inspection_eid = ?                              \n" );
        query.append( "   AND c_inspectionlist_eid = ?                          \n" );
        

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setString( 1, aesopinspectionlist.getDetect_position() );
            pstmt.setInt   ( 2, aesopinspectionlist.getDefect_weight() );
            pstmt.setInt   ( 3, aesopinspectionlist.getDefect_type() );
            pstmt.setInt   ( 4, aesopinspectionlist.getStage() );
            pstmt.setString( 5, aesopinspectionlist.getComments() );
            pstmt.setInt   ( 6, aesopinspectionlist.getFix_yn() );
            pstmt.setInt   ( 7, aesopinspectionlist.getFix_time() );
            pstmt.setInt   ( 8, aesopinspectionlist.getUser_eid() ); 
            pstmt.setInt   ( 9, aesopinspectionlist.getDocument_eid() );
            pstmt.setInt   (10, aesopinspectionlist.getOverview_eid() );
            pstmt.setInt   (11, aesopinspectionlist.getInspection_eid() );
            pstmt.setInt   (12, aesopinspectionlist.getInspectionlist_eid() );
            
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int reworkAesopinspectionlist( AesopinspectionlistDTO aesopinspectionlist ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_INSPECTIONLIST SET                             \n" );
        query.append( "        c_fix_yn = ?                                     \n" );
        query.append( "       ,c_fix_time = ?                                   \n" );
        query.append( " WHERE c_user_eid = ?                                    \n" );
        query.append( "   AND c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid = ?                                \n" );
        query.append( "   AND c_inspection_eid = ?                              \n" );
        query.append( "   AND c_inspectionlist_eid = ?                          \n" );
        

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesopinspectionlist.getFix_yn() );
            pstmt.setInt   ( 2, aesopinspectionlist.getFix_time() );
            pstmt.setInt   ( 3, aesopinspectionlist.getUser_eid() ); 
            pstmt.setInt   ( 4, aesopinspectionlist.getDocument_eid() );
            pstmt.setInt   ( 5, aesopinspectionlist.getOverview_eid() );
            pstmt.setInt   ( 6, aesopinspectionlist.getInspection_eid() );
            pstmt.setInt   ( 7, aesopinspectionlist.getInspectionlist_eid() );
            
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int deleteAesopinspectionlist( AesopinspectionlistDTO aesopinspectionlist ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_INSPECTIONLIST SET                             \n" );
        query.append( "        c_del_yn = 'Y'                                   \n" );
        query.append( " WHERE c_user_eid = ?                                    \n" );
        query.append( "   AND c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid = ?                                \n" );
        query.append( "   AND c_inspection_eid = ?                              \n" );
        query.append( "   AND c_inspectionlist_eid = ?                          \n" );
        
        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesopinspectionlist.getUser_eid() ); 
            pstmt.setInt   ( 2, aesopinspectionlist.getDocument_eid() );
            pstmt.setInt   ( 3, aesopinspectionlist.getOverview_eid() );
            pstmt.setInt   ( 4, aesopinspectionlist.getInspection_eid() );
            pstmt.setInt   ( 5, aesopinspectionlist.getInspectionlist_eid() );
        
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

}
