
/*
 * -----------------------------------------------------------------------------
 * File  Name     : AesopoverviewDAO.java
 * Description    : DAO class
 * Special Logics :
 * @author        : Suh Hyuck Jun
 * @version       : 1.0
 * @Date          : 2005.12.24
 *------------------------------------------------------------------------------
 * History :
 *  DATE              AUTHOR          DESCRIPTION
 * -----------      -------------    -------------------
 *  2005.12.24      Suh, Hyuck Jun    Initial Release
 *------------------------------------------------------------------------------
 * Copyright(c) 2004,  All rights reserved.
 *
 * NOTICE !    You can not copy or redistribute this code.
 *
 */
package cc.struts.cian3.aesopoverview.dao;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import cc.struts.cian3.dao.LoggableStatement;
import cc.struts.cian3.dao.SuperDAO;
import cc.struts.cian3.exception.DatabaseException;
import cc.struts.cian3.aesopoverview.dto.AesopoverviewDTO;


public class AesopoverviewDAO extends SuperDAO {
    static private final Log log = LogFactory.getLog(AesopoverviewDAO.class);



    public int insertAesopoverview( AesopoverviewDTO aesopoverview ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "INSERT INTO TB_OVERVIEW(                                 \n" );
        query.append( "                      c_document_eid                     \n" );
        query.append( "                     ,c_overview_eid                     \n" );
        query.append( "                     ,c_stored_filename0                 \n" );
        query.append( "                     ,c_org_filename0                    \n" );
        query.append( "                     ,c_stored_filename1                 \n" );
        query.append( "                     ,c_org_filename1                    \n" );
        query.append( "                     ,c_stored_filename2                 \n" );
        query.append( "                     ,c_org_filename2                    \n" );
        query.append( "                     ,c_stored_filename3                 \n" );
        query.append( "                     ,c_org_filename3                    \n" );
        query.append( "                     ,c_stored_filename4                 \n" );
        query.append( "                     ,c_org_filename4                    \n" );
        query.append( "                     ,c_inspection_expectation_date      \n" );
        query.append( "                     ,c_document_size                    \n" );
        query.append( "                     ,c_document_size_type               \n" );
        query.append( "                     ,c_del_yn                           \n" );
        query.append( "              )VALUES(                                   \n" );
        query.append( "                      ?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,'N'                                \n" );
        query.append( "              )                                          \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();
        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesopoverview.getDocument_eid() );
            pstmt.setInt   ( 2, aesopoverview.getOverview_eid() );
            pstmt.setString( 3, aesopoverview.getStored_filename0() );
            pstmt.setString( 4, aesopoverview.getOrg_filename0() );
            pstmt.setString( 5, aesopoverview.getStored_filename1() );
            pstmt.setString( 6, aesopoverview.getOrg_filename1() );
            pstmt.setString( 7, aesopoverview.getStored_filename2() );
            pstmt.setString( 8, aesopoverview.getOrg_filename2() );
            pstmt.setString( 9, aesopoverview.getStored_filename3() );
            pstmt.setString( 10, aesopoverview.getOrg_filename3() );
            pstmt.setString( 11, aesopoverview.getStored_filename4() );
            pstmt.setString( 12, aesopoverview.getOrg_filename4() );
            pstmt.setString( 13, aesopoverview.getInspection_expectation_date() );
            pstmt.setString( 14, aesopoverview.getDocument_size() );
            pstmt.setInt   ( 15, aesopoverview.getDocument_size_type() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int selectSeq( AesopoverviewDTO aesopoverview ) throws DatabaseException {
        int count = 0;
        StringBuffer query = new StringBuffer();
        query.append( "SELECT MAX(c_overview_eid) + 1 eid from TB_OVERVIEW where c_document_eid = ?           \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());
            
            pstmt.setInt( 1, aesopoverview.getDocument_eid()); 
            
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
              count= rs.getInt("eid");
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return count;

    }


    public AesopoverviewDTO[] selectAesopoverviewList( AesopoverviewDTO aesopoverview ) throws DatabaseException {
        AesopoverviewDTO[] arrDto = null;
        ArrayList list = new ArrayList();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                                   \n" );
        query.append( "        a.c_document_eid                  c_document_eid                 \n" );
        query.append( "       ,a.c_overview_eid                  c_overview_eid                 \n" );
        query.append( "       ,a.c_stored_filename0              c_stored_filename0             \n" );
        query.append( "       ,a.c_org_filename0                 c_org_filename0                \n" );
        query.append( "       ,a.c_stored_filename1              c_stored_filename1             \n" );
        query.append( "       ,a.c_org_filename1                 c_org_filename1                \n" );
        query.append( "       ,a.c_stored_filename2              c_stored_filename2             \n" );
        query.append( "       ,a.c_org_filename2                 c_org_filename2                \n" );
        query.append( "       ,a.c_stored_filename3              c_stored_filename3             \n" );
        query.append( "       ,a.c_org_filename3                 c_org_filename3                \n" );
        query.append( "       ,a.c_stored_filename4              c_stored_filename4             \n" );
        query.append( "       ,a.c_org_filename4                 c_org_filename4                \n" );
        query.append( "       ,a.c_inspection_expectation_date   c_inspection_expectation_date  \n" );
        query.append( "       ,a.c_document_size                 c_document_size                \n" );
        query.append( "       ,a.c_document_size_type            c_document_size_type           \n" );
        query.append( "       ,b.name                            c_document_size_type_lb        \n" );
        query.append( "  FROM TB_OVERVIEW a                                                     \n" );
        query.append( "      ,TB_CODE b                                                         \n" );
        query.append( " WHERE a.c_document_eid = ?                                              \n" );
        query.append( "   AND a.c_del_yn = 'N'                                                  \n" );
        query.append( "   AND a.c_document_size_type = b.class_id                               \n" );
        query.append( "   AND b.class_group = 2103                                              \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesopoverview.getDocument_eid()); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            while ( rs.next() ){
                AesopoverviewDTO dto = new AesopoverviewDTO();
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setOverview_eid( rs.getInt( "c_overview_eid" ) );
                dto.setStored_filename0( rs.getString( "c_stored_filename0" ) );
                dto.setOrg_filename0( rs.getString( "c_org_filename0" ) );
                dto.setStored_filename1( rs.getString( "c_stored_filename1" ) );
                dto.setOrg_filename1( rs.getString( "c_org_filename1" ) );
                dto.setStored_filename2( rs.getString( "c_stored_filename2" ) );
                dto.setOrg_filename2( rs.getString( "c_org_filename2" ) );
                dto.setStored_filename3( rs.getString( "c_stored_filename3" ) );
                dto.setOrg_filename3( rs.getString( "c_org_filename3" ) );
                dto.setStored_filename4( rs.getString( "c_stored_filename4" ) );
                dto.setOrg_filename4( rs.getString( "c_org_filename4" ) );
                dto.setInspection_expectation_date( rs.getString( "c_inspection_expectation_date" ) );
                dto.setDocument_size( rs.getString( "c_document_size" ) );
                dto.setDocument_size_type( rs.getInt( "c_document_size_type" ) );
                dto.setDocument_size_type_lb( rs.getString( "c_document_size_type_lb" ) );                

                list.add(dto);
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        arrDto = new AesopoverviewDTO[list.size()];
        list.toArray( arrDto );
        return arrDto;

    }

    public AesopoverviewDTO selectAesopoverview( AesopoverviewDTO aesopoverview ) throws DatabaseException {
        AesopoverviewDTO dto = new AesopoverviewDTO();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                                  \n" );
        query.append( "        a.c_document_eid                 c_document_eid                 \n" );
        query.append( "       ,a.c_overview_eid                 c_overview_eid                 \n" );
        query.append( "       ,a.c_stored_filename0             c_stored_filename0             \n" );
        query.append( "       ,a.c_org_filename0                c_org_filename0                \n" );
        query.append( "       ,a.c_stored_filename1             c_stored_filename1             \n" );
        query.append( "       ,a.c_org_filename1                c_org_filename1                \n" );
        query.append( "       ,a.c_stored_filename2             c_stored_filename2             \n" );
        query.append( "       ,a.c_org_filename2                c_org_filename2                \n" );
        query.append( "       ,a.c_stored_filename3             c_stored_filename3             \n" );
        query.append( "       ,a.c_org_filename3                c_org_filename3                \n" );
        query.append( "       ,a.c_stored_filename4             c_stored_filename4             \n" );
        query.append( "       ,a.c_org_filename4                c_org_filename4                \n" );
        query.append( "       ,a.c_inspection_expectation_date  c_inspection_expectation_date  \n" );
        query.append( "       ,a.c_document_size                c_document_size                \n" );
        query.append( "       ,a.c_document_size_type           c_document_size_type           \n" );
        query.append( "       ,b.name                           c_document_size_type_lb        \n" );
        query.append( "  FROM TB_OVERVIEW a                                                    \n" );
        query.append( "      ,TB_CODE b                                                        \n" );
        query.append( " WHERE a.c_document_eid = ?                                             \n" );
        query.append( "   AND a.c_overview_eid = ?                                             \n" );
        query.append( "   AND a.c_document_size_type = b.class_id                              \n" );
        query.append( "   AND b.class_group = 2103                                             \n" );
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesopoverview.getDocument_eid()); 
            pstmt.setInt( 2, aesopoverview.getOverview_eid()); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
                dto.setDocument_eid( rs.getInt( "c_document_eid" ) );
                dto.setOverview_eid( rs.getInt( "c_overview_eid" ) );
                dto.setStored_filename0( rs.getString( "c_stored_filename0" ) );
                dto.setOrg_filename0( rs.getString( "c_org_filename0" ) );
                dto.setStored_filename1( rs.getString( "c_stored_filename1" ) );
                dto.setOrg_filename1( rs.getString( "c_org_filename1" ) );
                dto.setStored_filename2( rs.getString( "c_stored_filename2" ) );
                dto.setOrg_filename2( rs.getString( "c_org_filename2" ) );
                dto.setStored_filename3( rs.getString( "c_stored_filename3" ) );
                dto.setOrg_filename3( rs.getString( "c_org_filename3" ) );
                dto.setStored_filename4( rs.getString( "c_stored_filename4" ) );
                dto.setOrg_filename4( rs.getString( "c_org_filename4" ) );
                dto.setInspection_expectation_date( rs.getString( "c_inspection_expectation_date" ) );
                dto.setDocument_size( rs.getString( "c_document_size" ) );
                dto.setDocument_size_type( rs.getInt( "c_document_size_type" ) );
                dto.setDocument_size_type_lb( rs.getString( "c_document_size_type_lb" ) );
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return dto;

    }



    public int updateAesopoverview( AesopoverviewDTO aesopoverview ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_OVERVIEW SET                                   \n" );
        query.append( "        c_stored_filename0 = ?                           \n" );
        query.append( "       ,c_org_filename0 = ?                              \n" );
        query.append( "       ,c_stored_filename1 = ?                           \n" );
        query.append( "       ,c_org_filename1 = ?                              \n" );
        query.append( "       ,c_stored_filename2 = ?                           \n" );
        query.append( "       ,c_org_filename2 = ?                              \n" );
        query.append( "       ,c_stored_filename3 = ?                           \n" );
        query.append( "       ,c_org_filename3 = ?                              \n" );
        query.append( "       ,c_stored_filename4 = ?                           \n" );
        query.append( "       ,c_org_filename4 = ?                              \n" );
        query.append( "       ,c_inspection_expectation_date = ?                \n" );
        query.append( "       ,c_document_size = ?                              \n" );
        query.append( "       ,c_document_size_type = ?                         \n" );
        query.append( " WHERE c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid = ?                                \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setString( 1, aesopoverview.getStored_filename0() );
            pstmt.setString( 2, aesopoverview.getOrg_filename0() );
            pstmt.setString( 3, aesopoverview.getStored_filename1() );
            pstmt.setString( 4, aesopoverview.getOrg_filename1() );
            pstmt.setString( 5, aesopoverview.getStored_filename2() );
            pstmt.setString( 6, aesopoverview.getOrg_filename2() );
            pstmt.setString( 7, aesopoverview.getStored_filename3() );
            pstmt.setString( 8, aesopoverview.getOrg_filename3() );
            pstmt.setString( 9, aesopoverview.getStored_filename4() );
            pstmt.setString( 10, aesopoverview.getOrg_filename4() );
            pstmt.setString( 11, aesopoverview.getInspection_expectation_date() );
            pstmt.setString( 12, aesopoverview.getDocument_size() );
            pstmt.setInt   ( 13, aesopoverview.getDocument_size_type() );
            pstmt.setInt   ( 14, aesopoverview.getDocument_eid() ); 
            pstmt.setInt   ( 15, aesopoverview.getOverview_eid() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }


    public int deleteAesopoverview( AesopoverviewDTO aesopoverview ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_OVERVIEW                                       \n" );
        query.append( "   SET c_del_yn = 'Y'                                    \n" );
        query.append( " WHERE c_document_eid = ?                                \n" );
        query.append( "   AND c_overview_eid = ?                                \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesopoverview.getDocument_eid() );
            pstmt.setInt   ( 2, aesopoverview.getOverview_eid() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

}
