
/*
 * -----------------------------------------------------------------------------
 * File  Name     : AesopuserDAO.java
 * Description    : DAO class
 * Special Logics :
 * @author        : Suh Hyuck Jun
 * @version       : 1.0
 * @Date          : 2005.12.24
 *------------------------------------------------------------------------------
 * History :
 *  DATE              AUTHOR          DESCRIPTION
 * -----------      -------------    -------------------
 *  2005.12.24      Suh, Hyuck Jun    Initial Release
 *------------------------------------------------------------------------------
 * Copyright(c) 2004,  All rights reserved.
 *
 * NOTICE !    You can not copy or redistribute this code.
 *
 */
package cc.struts.cian3.aesopuser.dao;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import cc.struts.cian3.dao.LoggableStatement;
import cc.struts.cian3.dao.SuperDAO;
import cc.struts.cian3.exception.DatabaseException;
import cc.struts.cian3.aesopuser.dto.AesopuserDTO;


public class AesopuserDAO extends SuperDAO {
    static private final Log log = LogFactory.getLog(AesopuserDAO.class);



    public int insertAesopuser( AesopuserDTO aesopuser ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "INSERT INTO TB_USER(                                     \n" );
        query.append( "                      c_user_eid                         \n" );
        query.append( "                     ,c_userid                           \n" );
        query.append( "                     ,c_name                             \n" );
        query.append( "                     ,c_password                         \n" );
        query.append( "                     ,c_email                            \n" );
        query.append( "                     ,c_use_yn                           \n" );
        query.append( "                     ,c_delete_yn                        \n" );
        query.append( "              )VALUES(                                   \n" );
        query.append( "                      ?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "              )                                          \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();
        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesopuser.getEid() );
            pstmt.setString( 2, aesopuser.getUserid() );
            pstmt.setString( 3, aesopuser.getName() );
            pstmt.setString( 4, aesopuser.getPassword() );
            pstmt.setString( 5, aesopuser.getEmail() );
            pstmt.setString( 6, aesopuser.getUse_yn() );
            pstmt.setString( 7, aesopuser.getDelete_yn() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int selectSeq() throws DatabaseException {
        int count = 0;
        StringBuffer query = new StringBuffer();
        query.append( "SELECT MAX(c_eid) + 1 eid from TB_USER                   \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
              count= rs.getInt("eid");
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return count;

    }


    public AesopuserDTO[] selectAesopuserList( AesopuserDTO aesopuser ) throws DatabaseException {
        AesopuserDTO[] arrDto = null;
        ArrayList list = new ArrayList();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        c_eid                                            \n" );
        query.append( "       ,c_userid                                         \n" );
        query.append( "       ,c_name                                           \n" );
        query.append( "       ,c_password                                       \n" );
        query.append( "       ,c_email                                          \n" );
        query.append( "       ,c_use_yn                                         \n" );
        query.append( "       ,c_delete_yn                                      \n" );
        query.append( "  FROM TB_USER                                           \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            while ( rs.next() ){
                AesopuserDTO dto = new AesopuserDTO();
                dto.setEid( rs.getInt( "c_user_eid" ) );
                dto.setUserid( rs.getString( "c_userid" ) );
                dto.setName( rs.getString( "c_name" ) );
                dto.setPassword( rs.getString( "c_password" ) );
                dto.setEmail( rs.getString( "c_email" ) );
                dto.setUse_yn( rs.getString( "c_use_yn" ) );
                dto.setDelete_yn( rs.getString( "c_delete_yn" ) );

                list.add(dto);
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        arrDto = new AesopuserDTO[list.size()];
        list.toArray( arrDto );
        return arrDto;

    }

    public AesopuserDTO selectAesopuser( AesopuserDTO aesopuser ) throws DatabaseException {
        AesopuserDTO dto = new AesopuserDTO();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        c_user_eid                                            \n" );
        query.append( "       ,c_userid                                         \n" );
        query.append( "       ,c_name                                           \n" );
        query.append( "       ,c_password                                       \n" );
        query.append( "       ,c_email                                          \n" );
        query.append( "       ,c_use_yn                                         \n" );
        query.append( "       ,c_delete_yn                                      \n" );
        query.append( "  FROM TB_USER                                           \n" );
        query.append( " WHERE c_user_eid = ?                                         \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, aesopuser.getEid()); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
                dto.setEid( rs.getInt( "c_user_eid" ) );
                dto.setUserid( rs.getString( "c_userid" ) );
                dto.setName( rs.getString( "c_name" ) );
                dto.setPassword( rs.getString( "c_password" ) );
                dto.setEmail( rs.getString( "c_email" ) );
                dto.setUse_yn( rs.getString( "c_use_yn" ) );
                dto.setDelete_yn( rs.getString( "c_delete_yn" ) );
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return dto;

    }



    public int updateAesopuser( AesopuserDTO aesopuser ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_USER SET                                       \n" );
        query.append( "        c_userid = ?                                     \n" );
        query.append( "       ,c_name = ?                                       \n" );
        query.append( "       ,c_password = ?                                   \n" );
        query.append( "       ,c_email = ?                                      \n" );
        query.append( "       ,c_use_yn = ?                                     \n" );
        query.append( "       ,c_delete_yn = ?                                  \n" );
        query.append( " WHERE c_user_eid = ?                                    \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setString( 1, aesopuser.getUserid() );
            pstmt.setString( 2, aesopuser.getName() );
            pstmt.setString( 3, aesopuser.getPassword() );
            pstmt.setString( 4, aesopuser.getEmail() );
            pstmt.setString( 5, aesopuser.getUse_yn() );
            pstmt.setString( 6, aesopuser.getDelete_yn() );
            pstmt.setInt   ( 7, aesopuser.getEid() ); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }


    public int deleteAesopuser( AesopuserDTO aesopuser ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "DELETE FROM TB_USER                                      \n" );
        query.append( " WHERE c_eid = ?                                         \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, aesopuser.getEid() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

}
