/*
 * -----------------------------------------------------------------------------
 * File  Name     : SuperDAO.java
 * Description    : Super class of all DAO classes
 * Special Logics :
 * @author        : Suh Hyuck Jun
 * @version       : 1.0
 * @Date          : 2004.07.20
 *------------------------------------------------------------------------------
 * History :
 *  DATE              AUTHOR          DESCRIPTION
 * -----------      -------------    -------------------
 *  2004.07.20      Suh, Hyuck Jun    Initial Release
 *------------------------------------------------------------------------------
 * Copyright(c) 2004,  All rights reserved.
 *
 * NOTICE !    You can not copy or redistribute this code.
 *
 */

package cc.struts.cian3.dao;

import java.sql.Connection;
import java.sql.SQLException; 
import java.util.ArrayList;
import java.util.Collection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import cc.struts.cian3.exception.DatabaseException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import cc.struts.cian3.dto.ComboDTO;

/**
 * Super class of all DAO classes.
 */

public class SuperDAO {
	static private final Log log = LogFactory.getLog(SuperDAO.class);
	
    private java.sql.Connection con = null;
    private final String url = "jdbc:mysql://";
    private final String serverName = "127.0.0.1";
    private final String portNumber = "3306";
    private final String databaseName = "cian";
    private final String charaterEncoding = "euckr";
    private final String userName = "root";
    private final String password = "pokipoki";

    protected boolean logEnabled = true;
    
    // Informs the driver to use server a side-cursor,
    // which permits more than one active statement
    // on a connection.
    private final String selectMethod = "cursor";

    // Constructor
    public SuperDAO() {}

    private String getConnectionUrl() {
    	String returnUrl="";
    	
        returnUrl = url + serverName + ":" + portNumber + "/" + databaseName + "?characterEncoding="+
                    charaterEncoding + "&user=" + userName + "&password=" + password;
        //System.out.println("url="+returnUrl);
        return returnUrl;
    }

    protected java.sql.Connection getConnection() {
        try {
        	Class.forName("com.mysql.jdbc.Driver").newInstance(); 
            con = java.sql.DriverManager.getConnection(getConnectionUrl());
            con.setAutoCommit( false );

            if (con != null) System.out.println("Connection Successful!");
    	} catch (SQLException ex) {
    		//handle any errors 
    		System.out.println("SQLException: " + ex.getMessage()); 
    		System.out.println("SQLState: " + ex.getSQLState()); 
    		System.out.println("VendorError: " + ex.getErrorCode()); 
    	}catch (Exception e) {
            e.printStackTrace();
            System.out.println("Error Trace in getConnection() : " +
                               e.getMessage());
        }
        return con;
    }

    /*
         Display the driver properties, database details
     */



    protected void closeConnection( Connection con ) {
        try {
            if (con != null)
                con.close();
            con = null;
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }



    
    public Collection selectCodeList(int classGroup) throws DatabaseException {
    	
    	ArrayList list = new ArrayList();
    	
    	StringBuffer query = new StringBuffer();
        query.append( "SELECT name          pkey                       \n");
        query.append( "      ,value         combovalue                 \n");
        query.append( "  from TB_CODE                                  \n");
        query.append( " WHERE class_group = ?                          \n");
        query.append( "   AND use_yn = 'Y'                             \n");
        query.append( "order by orderby_seq                            \n");
        
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();
        
        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());
            
            pstmt.setInt( 1, classGroup );
            
            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );
            
            rs = pstmt.executeQuery();
            
            while ( rs.next() ){
            	list.add( new ComboDTO( rs.getInt( "combovalue"), rs.getString( "pkey")));
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        
        return list;
    	
    }

}
