
/*
 * -----------------------------------------------------------------------------
 * File  Name     : WordsearchDAO.java
 * Description    : DAO class
 * Special Logics :
 * @author        : Suh Hyuck Jun
 * @version       : 1.0
 * @Date          : 2006.09.25
 *------------------------------------------------------------------------------
 * History :
 *  DATE              AUTHOR          DESCRIPTION
 * -----------      -------------    -------------------
 *  2006.09.25      Suh, Hyuck Jun    Initial Release
 *------------------------------------------------------------------------------
 * Copyright(c) 2004,  All rights reserved.
 *
 * NOTICE !    You can not copy or redistribute this code.
 *
 */
package cc.struts.cian3.wordsearch.dao;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import cc.struts.cian3.dao.LoggableStatement;
import cc.struts.cian3.dao.SuperDAO;
import cc.struts.cian3.exception.DatabaseException;
import cc.struts.cian3.wordsearch.dto.WordsearchDTO;


public class WordsearchDAO extends SuperDAO {
    static private final Log log = LogFactory.getLog(WordsearchDAO.class);



    public int insertWordsearch( WordsearchDTO wordsearch ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "INSERT INTO TB_WORD(                                     \n" );
        query.append( "                      c_eid                              \n" );
        query.append( "                     ,c_word                             \n" );
        query.append( "                     ,c_tagging                          \n" );
        query.append( "                     ,c_description                      \n" );
        query.append( "              )VALUES(                                   \n" );
        query.append( "                      ?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "                     ,?                                  \n" );
        query.append( "              )                                          \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();
        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, wordsearch.getEid() );
            pstmt.setString( 2, wordsearch.getWord() );
            pstmt.setString( 3, wordsearch.getTagging() );
            pstmt.setString( 4, wordsearch.getDescription() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int selectSeq() throws DatabaseException {
        int count = 0;
        StringBuffer query = new StringBuffer();
        query.append( "SELECT MAX(c_eid) + 1 eid from TB_WORD                   \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
              count= rs.getInt("eid");
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return count;

    }


    public WordsearchDTO[] selectWordsearchList( WordsearchDTO wordsearch ) throws DatabaseException {
        WordsearchDTO[] arrDto = null;
        ArrayList list = new ArrayList();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        c_eid                                            \n" );
        query.append( "       ,c_word                                           \n" );
        query.append( "       ,c_tagging                                        \n" );
        query.append( "       ,c_description                                    \n" );
        query.append( "  FROM TB_WORD                                           \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            while ( rs.next() ){
                WordsearchDTO dto = new WordsearchDTO();
                dto.setEid( rs.getInt( "c_eid" ) );
                dto.setWord( rs.getString( "c_word" ) );
                dto.setTagging( rs.getString( "c_tagging" ) );
                dto.setDescription( rs.getString( "c_description" ) );

                list.add(dto);
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        arrDto = new WordsearchDTO[list.size()];
        list.toArray( arrDto );
        return arrDto;

    }

    public WordsearchDTO selectWordsearch( WordsearchDTO wordsearch ) throws DatabaseException {
        WordsearchDTO dto = new WordsearchDTO();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        c_eid                                            \n" );
        query.append( "       ,c_word                                           \n" );
        query.append( "       ,c_tagging                                        \n" );
        query.append( "       ,c_description                                    \n" );
        query.append( "  FROM TB_WORD                                           \n" );
        query.append( " WHERE c_eid = ?                                         \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt( 1, wordsearch.getEid()); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
                dto.setEid( rs.getInt( "c_eid" ) );
                dto.setWord( rs.getString( "c_word" ) );
                dto.setTagging( rs.getString( "c_tagging" ) );
                dto.setDescription( rs.getString( "c_description" ) );
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return dto;

    }

    // String ˻ϱ.
    public WordsearchDTO selectWordsearchStr( WordsearchDTO wordsearch ) throws DatabaseException {
        WordsearchDTO dto = new WordsearchDTO();

        StringBuffer query = new StringBuffer();
        query.append( "SELECT                                                   \n" );
        query.append( "        c_eid                                            \n" );
        query.append( "       ,c_word                                           \n" );
        query.append( "       ,c_tagging                                        \n" );
        query.append( "       ,c_description                                    \n" );
        query.append( "  FROM TB_WORD                                           \n" );
        query.append( " WHERE c_word = ?                                        \n" );

        PreparedStatement pstmt = null;
        ResultSet rs = null;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setString( 1, wordsearch.getWord().trim()); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            rs = pstmt.executeQuery();

            if (rs.next()) {
                dto.setEid( rs.getInt( "c_eid" ) );
                dto.setWord( rs.getString( "c_word" ) );
                dto.setTagging( rs.getString( "c_tagging" ) );
                dto.setDescription( rs.getString( "c_description" ) );
            }
        }
        catch (Exception e) {
            e.printStackTrace();
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }

        return dto;

    }



    public int updateWordsearch( WordsearchDTO wordsearch ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_WORD SET                                       \n" );
        query.append( "        c_word = ?                                       \n" );
        query.append( "       ,c_tagging = ?                                    \n" );
        query.append( "       ,c_description = ?                                \n" );
        query.append( " WHERE c_eid = ?                                         \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setString( 1, wordsearch.getWord() );
            pstmt.setString( 2, wordsearch.getTagging() );
            pstmt.setString( 3, wordsearch.getDescription() );
            pstmt.setInt   ( 4, wordsearch.getEid() ); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    // ȸ 1 Ų.
    public int updateWordsearchViewCount( int eid ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "UPDATE TB_WORD SET                                       \n" );
        query.append( "        c_viewcount = c_viewcount + 1                    \n" );
        query.append( "       ,c_viewdate  = now()                              \n" );
        query.append( " WHERE c_eid = ?                                         \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, eid ); 

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

    public int deleteWordsearch( WordsearchDTO wordsearch ) throws DatabaseException {
        StringBuffer query = new StringBuffer();
        query.append( "DELETE FROM TB_WORD                                      \n" );
        query.append( " WHERE c_eid = ?                                         \n" );

        PreparedStatement pstmt = null;
        int count = 0;
        Connection conn = null;
        conn = getConnection();

        try {
            if(logEnabled) pstmt = new LoggableStatement(conn,query.toString());
            else pstmt = conn.prepareStatement(query.toString());

            pstmt.setInt   ( 1, wordsearch.getEid() );

            if(logEnabled) log.warn(((LoggableStatement)pstmt).getQueryString());
            else log.warn( query.toString() );

            count = pstmt.executeUpdate();

            conn.commit();
        }
        catch (Exception e) {
            e.printStackTrace();
            try{ conn.rollback(); }catch(SQLException sqlex){sqlex.printStackTrace();}
            throw new DatabaseException();
        }
        finally {
            try {closeConnection( conn );} catch (Exception e) { /*do nothing*/}
        }
        return count;

    }

}
